Option Explicit On 

Module T4W

    ' Error Codes

Public Const T4_NOERROR As Integer = &H0

Public Const T4_NOTAG = &H1
Public Const T4_DATAERROR = &H2
Public Const T4_WRITEERROR = &H3
Public Const T4_ADRESSERROR = &H4
Public Const T4_WRONGTAG = &H5
Public Const T4_READERROR = &H6
Public Const T4_NOTSELECTED = &H7
Public Const T4_WRONGTAGPW = &H8

Public Const T4_PARAERRWRITE = &H10
Public Const T4_PARANOTVALID = &H11
Public Const T4_PARAERRPWCYCLE = &H12
Public Const T4_PARANOLOGIN = &H13
Public Const T4_PARAWRONGPW = &H14

Public Const T4_READERCHPWFAIL = &H60

Public Const T4_UNKNOWNCOMMAND = &H80
Public Const T4_WRONGLENGTH = &H81
Public Const T4_CMDNOTAVAILABLE = &H82
Public Const T4_COMERRORRFMODULE = &H83

Public Const T4_RX_WRONGLENGTH = &H93
Public Const T4_WRONGBLOCKCNT = &H95
Public Const T4_POLLNOTINIT = &H96

Public Const T4_ALREADYINIT = &HA0
Public Const T4_NOTINIT = &HA1
Public Const T4_V24_INITFAIL = &HA2
Public Const T4_NOREADERSELECTED = &HA4

Public Const T4_RX_TIMEOUT = &HB1
Public Const T4_RX_WRONGANSWER = &HB2
Public Const T4_RX_WRONGCSUM = &HB3
Public Const T4_RX_PARITY = &HB4
Public Const T4_RX_OVERRUN = &HB5
Public Const T4_RX_FRAME = &HB6

' Definitions of Transpondertypes

Public Const T4_TYPE_IDRO_A = 0
Public Const T4_TYPE_IDRW_B = 1
Public Const T4_TYPE_IDRW_C = 2
Public Const T4_TYPE_IDRW_D = 3
Public Const T4_TYPE_IDRW_E = 4
Public Const T4_TYPE_IDRO_G = 5

Public Const T4_MSK_IDRO_A = &H1
Public Const T4_MSK_IDRW_B = &H2
Public Const T4_MSK_IDRW_C = &H4
Public Const T4_MSK_IDRW_D = &H8
Public Const T4_MSK_IDRW_E = &H10
Public Const T4_MSK_IDRO_G = &H20

' Following conversions of C++ prototypes:

' parameters:
' -----------
' unsigned char    -> ByVal As Byte
' BYTE             -> ByVal As Byte
' BYTE * (1 byte)  -> ByRef As Byte
' BYTE * (>1 byte) -> ByRef As Byte (specify the first element of the array of bytes)

' example for retrieving an array of bytes
' ----------------------------------------
' Dim Data(1..5) As Byte           ' this is our variable
' T4ReadVersionTagReader(Data(1))  ' specify the first element of the array!

' return types:
' -------------
' int            -> Integer
' const TCHAR *  -> String
' LPCTSTR        -> String

    ' Initialization/Deinitialization
    Declare Function T4FindCOMPortNr Lib "t4w.dll" Alias "_T4FindCOMPortNr@0" () As Integer
    Declare Function T4Init Lib "t4w.dll" Alias "_T4Init@4" (ByVal ComPort As String) As Integer
    Declare Function T4DeInit Lib "t4w.dll" Alias "_T4DeInit@0" () As Integer

    ' Selecting a Tag
Declare Function T4SelectTag Lib "t4w.dll" Alias "_T4SelectTag@8" (ByRef TagType As Byte, ByRef SerialNumber As Byte) As Integer
Declare Function T4SelectTagPW Lib "t4w.dll" Alias "_T4SelectTagPW@12" (ByRef PassWord As Byte, ByRef TagType As Byte, ByRef SerialNumber As Byte) As Integer
Declare Function T4InitTagPoll Lib "t4w.dll" Alias "_T4InitTagPoll@4" (ByRef PassWord As Byte) As Integer
Declare Function T4DoTagPoll Lib "t4w.dll" Alias "_T4DoTagPoll@8" (ByRef TagType As Byte, ByRef SerialNumber As Byte) As Integer

' Reading/Writing Tags
Declare Function T4WriteData Lib "t4w.dll" Alias "_T4WriteData@12" (ByVal BlockAdress As Byte, ByVal BlockCount As Byte, ByRef Data As Byte) As Integer
Declare Function T4ReadData Lib "t4w.dll" Alias "_T4ReadData@12" (ByVal BlockAdress As Byte, ByVal BlockCount As Byte, ByRef Data As Byte) As Integer
Declare Function T4WriteConfigData Lib "t4w.dll" Alias "_T4WriteConfigData@8" (ByVal BlockAdress As Byte, ByRef Data As Byte) As Integer
Declare Function T4ReadConfigData Lib "t4w.dll" Alias "_T4ReadConfigData@8" (ByVal BlockAdress As Byte, ByRef Data As Byte) As Integer

' Configuring the Transponder Reader
Declare Function T4ConfigurationReset Lib "t4w.dll" Alias "_T4ConfigurationReset@0" () As Integer
Declare Function T4SetTagDriver Lib "t4w.dll" Alias "_T4SetTagDriver@4" (ByVal Driver As Byte) As Integer
Declare Function T4SetTagOptions Lib "t4w.dll" Alias "_T4SetTagOptions@8" (ByVal TagType As Byte, ByVal TagOptions As Byte) As Integer

' Configuring I/O Ports
Declare Function T4IOSetConfig Lib "t4w.dll" Alias "_T4IOSetConfig@8" (ByVal IODirection As Byte, ByVal IOLevel As Byte) As Integer
Declare Function T4IOSetDefaults Lib "t4w.dll" Alias "_T4IOSetDefaults@4" (ByVal IODefaultValue As Byte) As Integer

' Reading/Writing I/O Ports
Declare Function T4IOReadInputs Lib "t4w.dll" Alias "_T4IOReadInputs@4" (ByRef InputState As Byte) As Integer
Declare Function T4IOSetOutputs Lib "t4w.dll" Alias "_T4IOSetOutputs@4" (ByVal SetBits As Byte) As Integer
Declare Function T4IOClearOutputs Lib "t4w.dll" Alias "_T4IOClearOutputs@4" (ByVal ClearBits As Byte) As Integer
Declare Function T4IOBeep Lib "t4w.dll" Alias "_T4IOBeep@12" (ByVal BeepBits As Byte, ByVal Duration As Byte, ByVal Frequency As Byte) As Integer

' Reading Versions
Declare Function T4VersionTagReader Lib "t4w.dll" Alias "_T4VersionTagReader@4" (ByRef Version As Byte) As Integer
Declare Function T4VersionLibrary Lib "t4w.dll" Alias "_T4VersionLibrary@0" () As Integer

' Misc
Declare Function T4GetStatusString Lib "t4w.dll" Alias "_T4GetStatusString@0" () As String

End Module
